@@ -19,6 +19,18 @@ module LDBlogWriter
       return @doc.elements['entry/link'].attributes['href']
     end
 
+    def collection_uri
+      uri_a = []
+      @doc.each_element('service/workspace/collection') do |e|
+        uri_a.push(e.attributes['href'])
+      end
+      uri_a
+    end
+
+    def media_src
+      return @doc.elements['entry/content'].attributes['src']
+    end
+
     def title
       return @doc.elements['entry/title'].text
     end
