@@ -1,7 +1,7 @@
 module LDBlogWriter
   class Config
-    attr_accessor :atom_api_uri, :categories_uri
-    attr_accessor :post_uri, :upload_uri, :username, :password
+    attr_accessor :atom_api_uri, :categories_uri, :atompub_uri
+    attr_accessor :post_uri, :upload_uri, :username, :password, :api_key
     attr_accessor :edit_uri_file, :upload_uri_file
     attr_accessor :convert_to_html, :html_directory
     attr_accessor :plugin_dir
@@ -13,13 +13,16 @@ module LDBlogWriter
     attr_accessor :service
     attr_accessor :auth_type
 
-    def initialize(filename)
+    def initialize(filename = nil)
       @options = Hash.new
       @auto_trackback = false
       @blog_title = ""
       @service = 'livedoor'
       @auth_type = 'wsse'
-      load(filename)
+      if filename != nil
+#        puts filename
+        load(filename)
+      end
     end
 
     def load(filename)
