@@ -1,8 +1,14 @@
+# -*- coding: utf-8 -*-
+
 module LDBlogWriter
   class Plugin
+    attr_accessor :post_process_list
+
     def initialize(conf)
       @conf = conf
+      @post_process_list = Array.new
       if @conf.plugin_dir != nil
+        load_plugins('ldblogwriter/lib/plugin')
         load_plugins(@conf.plugin_dir)
       end
     end
@@ -33,20 +39,12 @@ module LDBlogWriter
         "Plugin error"
       end
     end
-  end
-end
 
-if $0 == __FILE__
-#  require 'test-plugin.rb'
-  $test = true
-end
-
-if defined?($test) && $test
-  require 'test/unit'
-
-  class TestPlugin < Test::Unit::TestCase
-    def setup
+    def eval_post(entry)
+      @entry = entry # FIXME
+      @post_process_list.each do |post_process|
+        eval_src(post_process)
+      end
     end
-
   end
 end
